@@ -13,11 +13,7 @@
 
 #include "screen.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 XRandRScreen::XRandRScreen(XRandRConfig *config)
     : QObject(config)
@@ -68,3 +64,5 @@ void XRandRScreen::updateKScreenScreen(KScreen::ScreenPtr &screen) const
 {
     screen->setCurrentSize(m_currentSize);
 }
+
+#include "moc_xrandrscreen.cpp"
